==> 0.0.13.tar.gz: lib/antsomi.dart <==
import 'dart:async';

import 'antsomi_platform_interface.dart';
import 'catalog.dart';
import 'cdp_event.dart';
import 'inbox_items.dart';
import 'modify_action.dart';

class Antsomi {
  void track({required CDPEvent event}) {
    return AntsomiPlatform.instance.track(event: event);
  }

  void trackScreen(
      {required String name, String title = "", String type = ""}) {
    return AntsomiPlatform.instance
        .trackScreen(name: name, title: title, type: type);
  }

  Future<String?> getPlatformVersion() {
    return AntsomiPlatform.instance.getPlatformVersion();
  }

  Future<void> setCustomerProperties(
      {required String customerId,
      Map<String, String>? customerProperties}) async {
    return AntsomiPlatform.instance.setCustomerProperties(
        customerId: customerId, customerProperties: customerProperties);
  }

  Future<bool?> config(
      {required String portalId,
      required String propsId,
      required String appGroupId,
      required String applicationId}) {
    return AntsomiPlatform.instance.config(
        appGroupId: appGroupId,
        portalId: portalId,
        propsId: propsId,
        applicationId: applicationId);
  }

  Future appInboxInit(
      {required String destinationId, required String audienceType}) {
    return AntsomiPlatform.instance
        .appInboxInit(destinationId: destinationId, audienceType: audienceType);
  }

  Future<List<InboxItem>> getMessage(
      {List<String>? catalogId = const [], required int page}) {
    return AntsomiPlatform.instance
        .getMessage(catalogId: catalogId, page: page);
  }

  void parseDeepLink(Uri url) {
    return AntsomiPlatform.instance.parseDeepLink(url);
  }

  Future<String?> getUID() {
    return AntsomiPlatform.instance.getUID();
  }

  Future<String?> getCustomerId() async {
    return AntsomiPlatform.instance.getCustomerId();
  }

  Future<String?> getPropsId() async {
    return AntsomiPlatform.instance.getPropsId();
  }

  Future<String?> getPortalId() async {
    return AntsomiPlatform.instance.getPortalId();
  }

  Future<String?> getDeviceId() async {
    return AntsomiPlatform.instance.getDeviceId();
  }

  Future<int?> getUnreadMessageCount() {
    return AntsomiPlatform.instance.getUnreadMessageCount();
  }

  Future<List<Catalog>> getAllLabels() {
    return AntsomiPlatform.instance.getAllLabels();
  }

  Future<Map<String, String>> getMessageById({required String messageId}) {
    return AntsomiPlatform.instance.getMessageById(messageId: messageId);
  }

  Future<String?> getContext() {
    return AntsomiPlatform.instance.getContext();
  }

  void onNewMessageReceived(
      {required Function(InboxItem callbackValue) callback}) {
    AntsomiPlatform.instance.onNewMessageReceived(callback);
  }

  void handleDeepLink({required Function(String value) deepLinkHandler}) {
    AntsomiPlatform.instance.deepLinkHandler = deepLinkHandler;
  }

  void modifyAction({required String messageId, required ActionType action}) {
    AntsomiPlatform.instance.modifyAction(messageId: messageId, action: action);
  }

  void setDefaultAction({required void Function() action}) {
    AntsomiPlatform.instance.setDefaultAction = action;
  }

  void setPageLimit({required int limit}) {
    AntsomiPlatform.instance.setPageLimit(limit: limit);
  }
}

==> 0.0.23.tar.gz: lib/antsomi.dart <==
import 'dart:async';

import 'antsomi_platform_interface.dart';
import 'catalog.dart';
import 'cdp_event.dart';
import 'inbox_items.dart';
import 'modify_action.dart';

class Antsomi {
  void track({required CDPEvent event}) {
    return AntsomiPlatform.instance.track(event: event);
  }

  void trackScreen(
      {required String name, String title = "", String type = ""}) {
    return AntsomiPlatform.instance
        .trackScreen(name: name, title: title, type: type);
  }

  Future<String?> getPlatformVersion() {
    return AntsomiPlatform.instance.getPlatformVersion();
  }

  Future<void> setCustomerProperties(
      {required String customerId,
      Map<String, String>? customerProperties}) async {
    return AntsomiPlatform.instance.setCustomerProperties(
        customerId: customerId, customerProperties: customerProperties);
  }

  Future<bool?> config(
      {required String portalId,
      required String propsId,
      required String appGroupId,
      required String applicationId}) {
    return AntsomiPlatform.instance.config(
        appGroupId: appGroupId,
        portalId: portalId,
        propsId: propsId,
        applicationId: applicationId);
  }

  Future appInboxInit(
      {required String destinationId, required String audienceType}) {
    return AntsomiPlatform.instance
        .appInboxInit(destinationId: destinationId, audienceType: audienceType);
  }

  Future<List<InboxItem>> getMessage(
      {List<String>? catalogId = const [], required int page}) {
    return AntsomiPlatform.instance
        .getMessage(catalogId: catalogId, page: page);
  }

  void parseDeepLink(Uri url) {
    return AntsomiPlatform.instance.parseDeepLink(url);
  }

  Future<String?> getUID() {
    return AntsomiPlatform.instance.getUID();
  }

  Future<String?> getCustomerId() async {
    return AntsomiPlatform.instance.getCustomerId();
  }

  Future<String?> getPropsId() async {
    return AntsomiPlatform.instance.getPropsId();
  }

  Future<String?> getPortalId() async {
    return AntsomiPlatform.instance.getPortalId();
  }

  Future<String?> getDeviceId() async {
    return AntsomiPlatform.instance.getDeviceId();
  }

  Future<int?> getUnreadMessageCount() {
    return AntsomiPlatform.instance.getUnreadMessageCount();
  }

  Future<List<Catalog>> getAllLabels() {
    return AntsomiPlatform.instance.getAllLabels();
  }

  Future<Map<String, String>> getMessageById({required String messageId}) {
    return AntsomiPlatform.instance.getMessageById(messageId: messageId);
  }

  Future<String?> getContext() {
    return AntsomiPlatform.instance.getContext();
  }

  void onNewMessageReceived(
      {required Function(InboxItem callbackValue) callback}) {
    AntsomiPlatform.instance.onNewMessageReceived(callback);
  }

  void handleDeepLink({required Function(String value) deepLinkHandler}) {
    AntsomiPlatform.instance.deepLinkHandler = deepLinkHandler;
  }

  void modifyAction({required List<String> messageId, required int action}) {
    AntsomiPlatform.instance.modifyAction(messageId: messageId, action: action);
  }

  void setDefaultAction({required void Function() action}) {
    AntsomiPlatform.instance.setDefaultAction = action;
  }

  void setPageLimit({required int limit}) {
    AntsomiPlatform.instance.setPageLimit(limit: limit);
  }
}
